/************************************
GENERIC_EEPROM.C
read/write EEPROM

Author: Steve Covert
Date: 01-07-2010

Since we want to read/write ONE BYTE at a time, we have
declared a "char *" as the pointer to the variable:
  void EEPROM_GET(char *ptr,int num,int addr)
So this means we have to typecast the address we pass
to routines as a CHAR* (pointer to ONE BYTE). We typecast
the address by using syntax (char*)(&variable).

EXAMPLE: EEPROM_PUT((char*)&trx,sizeof(STRUCT PID),0);
PARAMETERS:
pointer to object (&foo = address of 1st byte of foo)
number of bytes (using 'sizeof' will always be correct!)
address to write to (up to you to keep from overlapping!)

Structures: Can write whole system setup without all the
conversions, individ addresses, etc., in ONE line of code!
EXAMPLE: structures to/from eeprom:
struct FOO
{
       char foo1;
       char foo2;
       float foo3;
       int foo4;
}trx;

Examples using STRUCT:
EEPROM_PUT((char*)&pid,sizeof(STRUCT PID),0);
EEPROM_GET((char*)&pid,sizeof(STRUCT PID),0);

Examples: floats to/from eeprom:
EEPROM_PUT((char*)&floatname,sizeof(float),0);
EEPROM_GET((char*)&floatname,sizeof(float),0);
*************************************/

#include "generic_eeprom.h"

int count;

/************************************
  STRUCT/ARRAY FUNCTIONS
*************************************/
void EEPROM_GET(char *ptr,int num,int addr) 
{
   for (count=0;count<num;count++)
   {
      ptr[count]=EEPROM_Read(addr+count);  // read 1 byte
      Delay_ms(1);
      asm nop;
   }
}

void EEPROM_PUT(char *ptr,int num,int addr) 
{
   for (count=0;count<num;count++)
   {
      EEPROM_Write(addr+count,ptr[count]); // write 1 byte
      Delay_ms(1);
      asm nop;
   }
}